@@ -1,15 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2012 Vincent Jacques <vincent@vincent-jacques.net>                 #
 # Copyright 2012 Zearin <zearin@gonk.net>                                      #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
 # Copyright 2013 Michael Stead <michael.stead@gmail.com>                       #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Jannis Gebauer <ja.geb@me.com>                                #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2017 Nicolas Agustín Torres <nicolastrres@gmail.com>              #
+# Copyright 2018 Wan Liuyang <tsfdye@gmail.com>                                #
+# Copyright 2018 per1234 <accounts@perglass.com>                               #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -24,16 +31,17 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 import github.GithubObject
-
 import github.NamedUser
 
+import Consts
+
 
 class IssueComment(github.GithubObject.CompletableGithubObject):
     """
-    This class represents IssueComments as returned for example by http://developer.github.com/v3/todo
+    This class represents IssueComments. The reference can be found here https://developer.github.com/v3/issues/comments/
     """
 
     def __repr__(self):
@@ -133,7 +141,7 @@ class IssueComment(github.GithubObject.CompletableGithubObject):
     def get_reactions(self):
         """
         :calls: `GET /repos/:owner/:repo/issues/comments/:id/reactions
-                <https://developer.github.com/v3/reactions/#list-reactions-for-an-issue-comment>`
+                <https://developer.github.com/v3/reactions/#list-reactions-for-an-issue-comment>`_
         :return: :class: :class:`github.PaginatedList.PaginatedList` of :class:`github.Reaction.Reaction`
         """
         return github.PaginatedList.PaginatedList(
@@ -141,7 +149,7 @@ class IssueComment(github.GithubObject.CompletableGithubObject):
             self._requester,
             self.url + "/reactions",
             None,
-            headers={'Accept': 'application/vnd.github.squirrel-girl-preview'}
+            headers={'Accept': Consts.mediaTypeReactionsPreview}
         )
 
     def create_reaction(self, reaction_type):
@@ -162,7 +170,7 @@ class IssueComment(github.GithubObject.CompletableGithubObject):
             "POST",
             self.url + "/reactions",
             input=post_parameters,
-            headers={'Accept': 'application/vnd.github.squirrel-girl-preview'}
+            headers={'Accept': Consts.mediaTypeReactionsPreview}
         )
         return github.Reaction.Reaction(self._requester, headers, data, completed=True)
 
