@@ -9,6 +9,9 @@
 # Copyright 2017 Chris McBride <thehighlander@users.noreply.github.com>        #
 # Copyright 2017 Simon <spam@esemi.ru>                                         #
 # Copyright 2018 Andrew Smith <espadav8@gmail.com>                             #
+# Copyright 2018 Daniel Kesler <kesler.daniel@gmail.com>                       #
+# Copyright 2018 Kuba <jakub.glapa@adspired.com>                               #
+# Copyright 2018 Maarten Fonville <mfonville@users.noreply.github.com>         #
 # Copyright 2018 Shinichi TAMURA <shnch.tmr@gmail.com>                         #
 # Copyright 2018 edquist <edquist@users.noreply.github.com>                    #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
@@ -62,6 +65,7 @@ class Release(Framework.TestCase):
         self.release = self.g.get_user().get_repo("PyGithub").get_releases()[0]
         self.assertEqual(self.release.id, 1210814)
         self.assertEqual(self.release.tag_name, "v1.25.2")
+        self.assertEqual(self.release.target_commitish, "master")
         self.assertEqual(self.release.upload_url, "https://uploads.github.com/repos/edhollandAL/PyGithub/releases/1210814/assets{?name}")
         self.assertEqual(self.release.body, "Body")
         self.assertEqual(self.release.title, "Test")
@@ -80,7 +84,7 @@ class Release(Framework.TestCase):
 
     def testDelete(self):
         self.release = self.g.get_user().get_repo("PyGithub").get_releases()[0]
-        self.assertTrue(self.release.delete_release())
+        self.release.delete_release()
 
     def testUpdate(self):
         self.release = self.g.get_user().get_repo("PyGithub").get_releases()[0]
